<?php
/**
 * Clase adaptadora para MySQL.
 *
 * @package PAR::Adapters
 * @author Manuel A. Rubio
 * @license GPL
 */
class PAR_Adapters_Mysql {

	/**
	 * Función para determinar al conversión de tipo
	 * del estándar SQL al tipo que emplea la base de
	 * datos específica.
	 *
	 * @param string $type tipo de dato SQL estándar.
	 * @param integer $size tamaño para tipos de datos como el de texto.
	 * @return string|boolean el tipo de dato o false en caso de no encontrarse.
	 */
	public function type( $type, $size = 255 ) {
		switch ($type) {
			case "string":
				settype($size, "int");
				$size = ($size <= 0) ? 255 : $size;
				return "varchar($size)";
			case "text":
			case "integer":
			case "real":
			case "boolean":
			case "date":
			case "time":
			case "datetime":
				return $type;
			case "autonumeric":
				return "int autoincrement";
			case "pkey":
				return "int autoincrement not null primary key";
		}
		return false;
	}

	/**
	 * Función para retornar el método de cada
	 * sistema gestor de base de datos para obtener
	 * la fecha actual.
	 *
	 * @return string la forma de recuperar la fecha actual.
	 */
	public function date_current() {
		return "CURRENT_DATE()";
	}
	
	/**
	 * Función para retornar el método de cada
	 * sistema gestor de base de datos para obtener
	 * la hora actual.
	 *
	 * @return string la forma de recuperar la hora actual.
	 */
	public function time_current() {
		return "CURRENT_TIME()";
	}

	/**
	 * Función para retornar el método de cada
	 * sistema gestor de base de datos para obtener
	 * la fecha y hora actual.
	 *
	 * @return string la forma de recuperar la fecha y hora actual.
	 */
	public function datetime_current() {
		return "CURRENT_DATETIME()";
	}

	/**
	 * Función que retorna el nombre de la clase, junto
	 * con el esquema en el que está definido.
	 *
	 * @param string $schema el nombre del esquema.
	 * @param string $name el nombre de la tabla.
	 * @return string el nombre de la tabla con esquema incluído.
	 */
	public function get_table_name( $schema, $name ) {
		return "`" . $schema . "`.`" . $name . "`";
	}

	/**
	 * Función para retornar el nombre de la columna.
	 *
	 * @param string $name nombre de la columna.
	 * @return string el nombre de la columna parseada.
	 */
	public function get_column_name( $name ) {
		return "`" . $name . "`";
	}
}
