<?php
/**
 * Clase adaptadora para SQLite.
 *
 * @package PAR::Adapters
 * @author Manuel A. Rubio
 * @license GPL
 */
class PAR_Adapters_Sqlite {
	
	/**
	 * Función para determinar al conversión de tipo
	 * del estándar SQL al tipo que emplea la base de
	 * datos específica.
	 *
	 * @param string $type tipo de dato SQL estándar.
	 * @param integer $size tamaño para tipos de datos como el de texto.
	 * @return string|boolean el tipo de dato o false en caso de no encontrarse.
	 */
	public function type( $type, $limit = 255 ) {
		switch ($type) {
			case "string":
				settype($limit, "int");
				$limit = ($limit <= 0) ? 255 : $limit;
				return "varchar($limit)";
			case "text":
			case "integer":
			case "real":
			case "boolean":
			case "date":
			case "time":
				return $type;
			case "datetime":
			case "timestamp":
				return "timestamp without time zone";
			case "autonumeric":
				return "integer autoincrement";
			case "pkey":
				return "integer not null primary key autoincrement";
		}
		return false;
	}
	
	/**
	 * Función para poder tomar una columna de tipo fecha
	 * de forma adecuada (según si tiene formato UTC o cualquier otro).
	 *
	 * @param string $field el nombre del campo.
	 * @return string el nombre del campo.
	 */
	public function select_date( $field ) {
		$parsed = $this->get_column_name($field);
		return "date($parsed, 'localtime') as $parsed";
	}
	
	/**
	 * Función que retorna el nombre de la clase, junto
	 * con el esquema en el que está definido.
	 *
	 * @param string $schema el nombre del esquema.
	 * @param string $name el nombre de la tabla.
	 * @return string el nombre de la tabla con esquema incluído.
	 */
	public function get_table_name( $schema, $name ) {
		$name = (!empty($schema)) ? '"' . $schema . '"."' . $name . '"' : '"' . $name . '"';
		return $name;
	}

	/**
	 * Función para retornar el nombre de la columna.
	 *
	 * @param string $name nombre de la columna.
	 * @return string el nombre de la columna parseada.
	 */
	public function get_column_name( $name ) {
		return '"' . $name . '"';
	}
}
